aboutsummaryrefslogtreecommitdiff
path: root/portal-gui/scripts/adduser.py
diff options
context:
space:
mode:
authorRob Austein <sra@hactrn.net>2011-01-20 20:48:56 +0000
committerRob Austein <sra@hactrn.net>2011-01-20 20:48:56 +0000
commitf667aeb2a42af39038fb10044405a6c02cc14531 (patch)
tree023172e6d23548069b4b91fa552d878cf44e0473 /portal-gui/scripts/adduser.py
parent7c26e04d89406d7af06d2ad2c951d9d50a797cf0 (diff)
UNTESTED changes to port-gui to match myrpki.conf => rpki.conf changes
into line with the other Python code portal-gui needs a bit more work to bring its autoconf into line with the other code, which may include some source tree reorganizations. svn path=/portal-gui/Makefile.in; revision=3621
Diffstat (limited to 'portal-gui/scripts/adduser.py')
-rwxr-xr-xportal-gui/scripts/adduser.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/portal-gui/scripts/adduser.py b/portal-gui/scripts/adduser.py
index b42e4687..27e73ed7 100755
--- a/portal-gui/scripts/adduser.py
+++ b/portal-gui/scripts/adduser.py
@@ -96,8 +96,8 @@ if __name__ == '__main__':
os.mkdir(myrpki_dir)
os.chown(myrpki_dir, web_uid, -1)
- # create stuf myrpki.conf enough to fool portal-gui
- myrpki_conf = myrpki_dir + '/myrpki.conf'
+ # create stuf rpki.conf enough to fool portal-gui
+ myrpki_conf = myrpki_dir + '/rpki.conf'
if not os.path.exists(myrpki_conf):
print 'creating ', myrpki_conf
with open(myrpki_conf, 'w') as f: